#!/bin/sh 

# Get list of files to backup
if [ ! -f $(dirname $0)/cfg_backup_list_of_files.sh ]; then
  echo "file containing list of files to backup not found !"
  exit 1
fi
. $(dirname $0)/cfg_backup_list_of_files.sh

# var
backup_folder=$PWD"/.backup_WAN_cfg"
hash_file="./md5_backup"
hash_file_full=$backup_folder"/"$hash_file
tmp_hash_file_full="/tmp/"$hash_file

# debug display
#
display_debug=1
_myecho()
{
  [ $display_debug -eq 1 ] && echo $*
}

# display list of files to backup
#
_display_list_of_backup_files()
{
  _myecho "Files to backup:"
  for file in $BACKUP_LIST_FILES_TO_BACKUP; do
    _myecho $file
  done
}

# _backup_files function
# copy list of files
# copy each file preserving its directory tree
#
_backup_files()
{
  #remove previous files
  rm -rf $backup_folder
  
  #copy files
  for file in $*; do
    path=$(dirname $file)
    folder=$backup_folder$path"/"
    mkdir -p $folder
    cp -a $file $folder
  done
}

# backup function
#
_backup_fct()
{
  echo "backup requested !"

  _display_list_of_backup_files

  # hash of files to backup
  md5sum $BACKUP_LIST_FILES_TO_BACKUP > $tmp_hash_file_full
  
  #compare with the previous hash
  dif=1
  if [ -f $hash_file_full ]; then
    cmp -s $hash_file_full $tmp_hash_file_full
    dif=$?
    _myecho "dif: "$dif
  fi
  
  # if no backup or file changes, do a backup
  if [ 0 -ne $dif ]; then
    _myecho "Backup the files"
    _backup_files $BACKUP_LIST_FILES_TO_BACKUP
    cp $tmp_hash_file_full $hash_file_full
  fi
  
  return $?
}


# _restore_fct function
# do restore files from a backup folder
#
_restore_fct()
{
  echo "restore requested !"

  cd $backup_folder
  _myecho "Folder to restore: "$PWD
  
  list_of_files=$(find . -type f)
  for file in $list_of_files; do
    # restore files except hashfile
    if [ "$file" != "$hash_file" ] ; then
      folder=$(dirname $file | cut -d. -f2)
      _myecho "where to restore file: "$folder
      mkdir -p $folder
      cp -a -f $file $folder"/"
    fi
  done

  return $?
}


# Test at least one argument is given
if [ $# -lt 1 ]; then
  _myecho "Error: no argument given !"
  action=-1
  exit 1
fi

ret=1

case $1 in
  "backup" )
    # backup functionality
    _backup_fct 
    ret=$?
  ;;
  "restore" )
    # restore functionality
    _restore_fct
    ret=$?
  ;;
  *)
    _myecho "error: bad argument !"
    exit 1
esac

_myecho "ret: "$ret
exit $ret
